# PatchedRemoteControlCommandRequest


## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**command** | [**CommandEnum**](CommandEnum.md) |  | [optional] 
**user** | **int** |  | [optional] 
**device** | **int** |  | [optional] 
**received** | **bool** |  | [optional] 
**success** | **bool** |  | [optional] 
**iotcore_response** | **dict(str, object)** |  | [optional] 
**metadata** | **dict(str, object)** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


